/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLScriptElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLScriptElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLScriptElement.h"
#include "gdom/PrivateIntGdomHTMLScriptElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLScriptElement::GDOMHTMLScriptElement(PassRefPtr<WebCore::HTMLScriptElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLScriptElement.h"
#include <gdom/GdomHTMLScriptElement.h>
#include <gdom/PrivateGdomHTMLScriptElement.h>
#include <gdom/PrivateIntGdomHTMLScriptElement.h>
#include <gdom/GdomHTMLScriptElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLScriptElement, gdom_html_script_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLScriptElementPrivate {
    class WebCore::HTMLScriptElement *item;
};

#define GDOM_HTML_SCRIPT_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_SCRIPT_ELEMENT, GdomHTMLScriptElementPrivate))
*/
G_END_DECLS
WebCore::HTMLScriptElement *
gdom_html_script_element_get_private(GdomHTMLScriptElement *request)
{
    GDOMHTMLScriptElement *res;
    res = static_cast<GDOMHTMLScriptElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLScriptElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_TEXT,
    PROP_HTML_FOR,
    PROP_EVENT,
    PROP_CHARSET,
    PROP_DEFER,
    PROP_SRC,
    PROP_TYPE,
};


static void gdom_html_script_element_finalize(GObject* object)
{
    /*GdomHTMLScriptElement* request = GDOM_HTML_SCRIPT_ELEMENT(object);*/
    /*GdomHTMLScriptElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_script_element_parent_class)->finalize(object);
}

static void gdom_html_script_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLScriptElement *self = GDOM_HTML_SCRIPT_ELEMENT(object);
    WebCore::HTMLScriptElement * gself = (gdom_html_script_element_get_private(self));
    switch (prop_id) {
     case PROP_TEXT:
    {
         gself->setText(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_HTML_FOR:
    {
         gself->setHtmlFor(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_EVENT:
    {
         gself->setEvent(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_CHARSET:
    {
         gself->setCharset(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_DEFER:
    {
         gself->setDefer((g_value_get_boolean (value)) );
         break;
    }
     case PROP_SRC:
    {
         gself->setSrc(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_TYPE:
    {
         gself->setType(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_script_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLScriptElement *self = GDOM_HTML_SCRIPT_ELEMENT(object);
    WebCore::HTMLScriptElement * gself = (gdom_html_script_element_get_private(self));
    switch (prop_id) {
    case PROP_TEXT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->text()));
         break;
    }
    case PROP_HTML_FOR:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->htmlFor()));
         break;
    }
    case PROP_EVENT:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->event()));
         break;
    }
    case PROP_CHARSET:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->charset()));
         break;
    }
    case PROP_DEFER:
    {
         g_value_set_boolean (value, gself->defer());
         break;
    }
    case PROP_SRC:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->src()));
         break;
    }
    case PROP_TYPE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->type()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_script_element_class_init(GdomHTMLScriptElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_script_element_finalize;
    g_klass->set_property = gdom_html_script_element__set_property_fn;
    g_klass->get_property = gdom_html_script_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_TEXT,
            g_param_spec_string ("text", /* name */
                "html_script_element_text", /* short description */
                "read-write  gchar * HTMLScriptElement.text", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_HTML_FOR,
            g_param_spec_string ("html_for", /* name */
                "html_script_element_html_for", /* short description */
                "read-write  gchar * HTMLScriptElement.html_for", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_EVENT,
            g_param_spec_string ("event", /* name */
                "html_script_element_event", /* short description */
                "read-write  gchar * HTMLScriptElement.event", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_CHARSET,
            g_param_spec_string ("charset", /* name */
                "html_script_element_charset", /* short description */
                "read-write  gchar * HTMLScriptElement.charset", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_DEFER,
            g_param_spec_boolean ("defer", /* name */
                "html_script_element_defer", /* short description */
                "read-write  gboolean HTMLScriptElement.defer", /* longer - could do with some extra doc stuff here */
                 FALSE, /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_SRC,
            g_param_spec_string ("src", /* name */
                "html_script_element_src", /* short description */
                "read-write  gchar * HTMLScriptElement.src", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_TYPE,
            g_param_spec_string ("type", /* name */
                "html_script_element_type", /* short description */
                "read-write  gchar * HTMLScriptElement.type", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLScriptElementPrivate));*/
}

static void gdom_html_script_element_init(GdomHTMLScriptElement* request)
{
    /*GdomHTMLScriptElementPrivate* priv = GDOM_HTML_SCRIPT_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

